==> haskell-brittany-0.13.1.0-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-brittany.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 brittany
version:              0.13.1.0
visibility:           public
id:                   brittany-0.13.1.0-8eMLDPkjWU1CcXwk3Lsgc8
key:                  brittany-0.13.1.0-8eMLDPkjWU1CcXwk3Lsgc8
license:              AGPL-3.0-only
copyright:
    Copyright (C) 2016-2019 Lennart Spitzner
    Copyright (C) 2019 PRODA LTD

maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/brittany/
synopsis:             Haskell source code formatter
description:
    See <https://github.com/lspitzner/brittany/blob/master/README.md the README>.

    If you are interested in the implementation, have a look at <https://github.com/lspitzner/brittany/blob/master/doc/implementation/theory.md this document>;

    The implementation is documented in more detail <https://github.com/lspitzner/brittany/blob/master/doc/implementation/index.md here>.

category:             Language
abi:                  2e84a549a57dd7aefaf612ae2b5ddf5a
exposed:              True
exposed-modules:
    Language.Haskell.Brittany Language.Haskell.Brittany.Internal
    Language.Haskell.Brittany.Internal.Config
    Language.Haskell.Brittany.Internal.Config.Types
    Language.Haskell.Brittany.Internal.Config.Types.Instances
    Language.Haskell.Brittany.Internal.Obfuscation
    Language.Haskell.Brittany.Internal.Prelude
    Language.Haskell.Brittany.Internal.PreludeUtils
    Language.Haskell.Brittany.Internal.Types
    Language.Haskell.Brittany.Internal.Utils
    Language.Haskell.Brittany.Main Paths_brittany

hidden-modules:
    Language.Haskell.Brittany.Internal.LayouterBasics
    Language.Haskell.Brittany.Internal.Backend
    Language.Haskell.Brittany.Internal.BackendUtils
    Language.Haskell.Brittany.Internal.ExactPrintUtils
    Language.Haskell.Brittany.Internal.Layouters.Type
    Language.Haskell.Brittany.Internal.Layouters.Decl
    Language.Haskell.Brittany.Internal.Layouters.Expr
    Language.Haskell.Brittany.Internal.Layouters.Stmt
    Language.Haskell.Brittany.Internal.Layouters.Pattern
    Language.Haskell.Brittany.Internal.Layouters.IE
    Language.Haskell.Brittany.Internal.Layouters.Import
    Language.Haskell.Brittany.Internal.Layouters.Module
    Language.Haskell.Brittany.Internal.Layouters.DataDecl
    Language.Haskell.Brittany.Internal.Transformations.Alt
    Language.Haskell.Brittany.Internal.Transformations.Floating
    Language.Haskell.Brittany.Internal.Transformations.Par
    Language.Haskell.Brittany.Internal.Transformations.Columns
    Language.Haskell.Brittany.Internal.Transformations.Indent

import-dirs:          /usr/lib/ghc-8.10.4/site-local/brittany-0.13.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/brittany-0.13.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/brittany-0.13.1.0
hs-libraries:         HSbrittany-0.13.1.0-8eMLDPkjWU1CcXwk3Lsgc8
depends:
    Cabal-3.2.1.0 aeson-1.5.6.0-CXL1oIyIKzV3Wzutw5KnI4 base-4.14.1.0
    butcher-1.3.3.2-4hBJlxX3L1F539zfFAhF5I bytestring-0.10.12.0
    cmdargs-0.10.21-KlHphs6sBhIECkIRkNdEOM containers-0.6.2.1
    czipwith-1.0.1.3-3vgoVUJklEuJUDH0PLL8nB
    data-tree-print-0.1.0.2-F52IvZTtP7r8TqIuEEMmmP deepseq-1.4.4.0
    directory-1.3.6.0 extra-1.7.9-DgbgOGN2Ikz1KvzYVralYk
    filepath-1.4.2.1 ghc-8.10.4 ghc-boot-th-8.10.4
    ghc-exactprint-0.6.3.4-5CueAWorLoG8dQHlr2aeyw
    ghc-paths-0.1.0.12-LgiNEBvorJD4Iq1vCUjVLQ
    monad-memo-0.5.3-FHcD0GKLCM1Bl8DKl28uDs mtl-2.2.2
    multistate-0.8.0.3-9JSwkyTVnITA7kjJUZTqGs pretty-1.1.3.6
    random-1.2.0-F9Db881XSkeHNx13RpGdSQ
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    strict-0.4.0.1-D0mzE3j2W6kDRmFZtrdQpw
    syb-0.7.2.1-JKZju2S4ac626Sffwf6Fw2 text-1.2.4.1
    transformers-0.5.6.2 uniplate-1.6.13-h2JmEyqhCWE4lrdwsDEzu
    unsafe-0.0-24urQzVt9PWBSwlXDCq1I6
    yaml-0.11.5.0-4qhUWAOWoCbG8fbKqpo0Rb

haddock-interfaces:   /usr/share/doc/haskell-brittany/html/brittany.haddock
haddock-html:         /usr/share/doc/haskell-brittany/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-brittany-0.13.1.0-71-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-brittany.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 brittany
version:              0.13.1.0
visibility:           public
id:                   brittany-0.13.1.0-FtXJlbxarFBA1NNx8fBpMC
key:                  brittany-0.13.1.0-FtXJlbxarFBA1NNx8fBpMC
license:              AGPL-3.0-only
copyright:
    Copyright (C) 2016-2019 Lennart Spitzner
    Copyright (C) 2019 PRODA LTD

maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/brittany/
synopsis:             Haskell source code formatter
description:
    See <https://github.com/lspitzner/brittany/blob/master/README.md the README>.

    If you are interested in the implementation, have a look at <https://github.com/lspitzner/brittany/blob/master/doc/implementation/theory.md this document>;

    The implementation is documented in more detail <https://github.com/lspitzner/brittany/blob/master/doc/implementation/index.md here>.

category:             Language
abi:                  221b28b85ab0d23787a1a262ff3f97ea
exposed:              True
exposed-modules:
    Language.Haskell.Brittany Language.Haskell.Brittany.Internal
    Language.Haskell.Brittany.Internal.Config
    Language.Haskell.Brittany.Internal.Config.Types
    Language.Haskell.Brittany.Internal.Config.Types.Instances
    Language.Haskell.Brittany.Internal.Obfuscation
    Language.Haskell.Brittany.Internal.Prelude
    Language.Haskell.Brittany.Internal.PreludeUtils
    Language.Haskell.Brittany.Internal.Types
    Language.Haskell.Brittany.Internal.Utils
    Language.Haskell.Brittany.Main Paths_brittany

hidden-modules:
    Language.Haskell.Brittany.Internal.LayouterBasics
    Language.Haskell.Brittany.Internal.Backend
    Language.Haskell.Brittany.Internal.BackendUtils
    Language.Haskell.Brittany.Internal.ExactPrintUtils
    Language.Haskell.Brittany.Internal.Layouters.Type
    Language.Haskell.Brittany.Internal.Layouters.Decl
    Language.Haskell.Brittany.Internal.Layouters.Expr
    Language.Haskell.Brittany.Internal.Layouters.Stmt
    Language.Haskell.Brittany.Internal.Layouters.Pattern
    Language.Haskell.Brittany.Internal.Layouters.IE
    Language.Haskell.Brittany.Internal.Layouters.Import
    Language.Haskell.Brittany.Internal.Layouters.Module
    Language.Haskell.Brittany.Internal.Layouters.DataDecl
    Language.Haskell.Brittany.Internal.Transformations.Alt
    Language.Haskell.Brittany.Internal.Transformations.Floating
    Language.Haskell.Brittany.Internal.Transformations.Par
    Language.Haskell.Brittany.Internal.Transformations.Columns
    Language.Haskell.Brittany.Internal.Transformations.Indent

import-dirs:          /usr/lib/ghc-8.10.4/site-local/brittany-0.13.1.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/brittany-0.13.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/brittany-0.13.1.0
hs-libraries:         HSbrittany-0.13.1.0-FtXJlbxarFBA1NNx8fBpMC
depends:
    Cabal-3.2.1.0 aeson-1.5.6.0-5UhD0HeD84KFPVsjqEyp8O base-4.14.1.0
    butcher-1.3.3.2-86BEIpvugeW8kxQT9ivihc bytestring-0.10.12.0
    cmdargs-0.10.21-KlHphs6sBhIECkIRkNdEOM containers-0.6.2.1
    czipwith-1.0.1.3-3vgoVUJklEuJUDH0PLL8nB
    data-tree-print-0.1.0.2-At54f15Ye9mJUP63P0FBif deepseq-1.4.4.0
    directory-1.3.6.0 extra-1.7.9-2iz2eeUzuSk6vWcWekkLY3
    filepath-1.4.2.1 ghc-8.10.4 ghc-boot-th-8.10.4
    ghc-exactprint-0.6.4-JYjz6UgbheX7rg9Gf9HgjN
    ghc-paths-0.1.0.12-LgiNEBvorJD4Iq1vCUjVLQ
    monad-memo-0.5.3-B0BvZNzoV9R6qPKWQpRjg mtl-2.2.2
    multistate-0.8.0.3-HqvDUg7jHlH9GTJpnTVsmJ pretty-1.1.3.6
    random-1.2.0-ItNHUQGxAZG6kpAc0uGzLq
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    strict-0.4.0.1-76F6okfxiorJeWrk9LigHT
    syb-0.7.2.1-LyGaJy3DdjiCurYoAQNPTw text-1.2.4.1
    transformers-0.5.6.2 uniplate-1.6.13-FuJ0TEOFeqFB6aN786Zop5
    unsafe-0.0-24urQzVt9PWBSwlXDCq1I6
    yaml-0.11.5.0-COR9EthOrkg1KFXwMb7Co0

haddock-interfaces:   /usr/share/doc/haskell-brittany/html/brittany.haddock
haddock-html:         /usr/share/doc/haskell-brittany/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
